@@ -1,5 +1,6 @@
-import pandas as pd # type: ignore
-import numpy as np # type: ignore
+import pandas as pd  # type: ignore
+import numpy as np  # type: ignore
+
 
 def average_weekly_data(tab_data_set) -> pd.DataFrame:
     """
@@ -8,7 +9,8 @@ def average_weekly_data(tab_data_set) -> pd.DataFrame:
 
     tab_data_set: Azure tabular dataset
     """
-    data : pd.DataFrame = tab_data_set.to_pandas_dataframe()
-    data['houroftheweek_average'] = data['houroftheweek_average'].astype(np.float32)
-    
+    data: pd.DataFrame = tab_data_set.to_pandas_dataframe()
+    data['houroftheweek_average'] = data['houroftheweek_average'].astype(
+        np.float32)
+
     return data
