@@ -17,12 +17,20 @@ def dayofweek(df: pd.DataFrame) -> pd.DataFrame:
     pandas.DataFrame
     
     """
+    # dayofweek_mapping = {0: 1, 1: 2, 2: 3, 3: 4, 4: 5, 5: 6, 6: 0}
+
+    # # Create day of week as a new feature (for example: 0-sunday, 6-saturday)
+    # initial_index: DatetimeIndex = df.index if isinstance(
+    #     df.index, DatetimeIndex) else pd.to_datetime(df.index)
+    # df["dayofweek"] = initial_index.dayofweek.map(dayofweek_mapping).astype(
+    #     np.float32)
+
+    # return df
     dayofweek_mapping = {0: 1, 1: 2, 2: 3, 3: 4, 4: 5, 5: 6, 6: 0}
 
     # Create day of week as a new feature (for example: 0-sunday, 6-saturday)
-    initial_index: DatetimeIndex = df.index if isinstance(
-        df.index, DatetimeIndex) else pd.to_datetime(df.index)
-    df["dayofweek"] = initial_index.dayofweek.map(dayofweek_mapping).astype(
-        np.float32)
+    df["dayofweek"] = df.index.dayofweek
+    df["dayofweek"] = df["dayofweek"].map(dayofweek_mapping)
+    df['dayofweek'] = df['dayofweek'].astype(np.float32)
 
-    return df
+    return df
\ No newline at end of file
