@@ -1,6 +1,5 @@
 import numpy as np  # type: ignore
 import pandas as pd  # type: ignore
-from pandas import DatetimeIndex
 
 
 def hourofday(df: pd.DataFrame) -> pd.DataFrame:
@@ -18,8 +17,13 @@ def hourofday(df: pd.DataFrame) -> pd.DataFrame:
     Pandas dataframe
     
     """
+    # # Create hours of day as a new feature (for example: 0-23)
+    # initial_index: DatetimeIndex = df.index if isinstance(
+    #     df.index, DatetimeIndex) else pd.to_datetime(df.index)
+    # df["hourofday"] = initial_index.hour.astype(np.float32)
+    # return df
+
     # Create hours of day as a new feature (for example: 0-23)
-    initial_index: DatetimeIndex = df.index if isinstance(
-        df.index, DatetimeIndex) else pd.to_datetime(df.index)
-    df["hourofday"] = initial_index.hour.astype(np.float32)
-    return df
+    df['hourofday'] = df.index.hour
+    df['hourofday'] = df['hourofday'].astype(np.float32)
+    return df
\ No newline at end of file
