@@ -1,5 +1,5 @@
-import numpy as np # type: ignore
-import pandas as pd # type: ignore
+import numpy as np  # type: ignore
+import pandas as pd  # type: ignore
 
 
 def monthyear(df: pd.DataFrame) -> pd.DataFrame:
@@ -10,15 +10,22 @@ def monthyear(df: pd.DataFrame) -> pd.DataFrame:
      # Parameters
      --------------
      df: Dataframe with datetime index
-     substation_id: refers to column name that keeps substation IDs
 
      # Returns
      --------------
-     Pandas dataframe
+     pd.DataFrame
     
      """
+
+    # # Create months of of a year as a new feature (for example: 1-Januar, 12-December)
+    # initial_index: DatetimeIndex = df.index if isinstance(
+    #     df.index, DatetimeIndex) else pd.to_datetime(df.index)
+    # df['monthyear'] = initial_index.month.astype(np.float32)
+
+    # return df
+
     # Create months of of a year as a new feature (for example: 1-Januar, 12-December)
     df['monthyear'] = df.index.month
     df['monthyear'] = df['monthyear'].astype(np.float32)
 
-    return df
+    return df
\ No newline at end of file
